@@ -213,8 +213,8 @@ main( int argc, char * argv[] ) {
     zero_order_frequencies freqs_with_pseudo_counts = freqs.add_pseudo_counts( 1. );
 	likelihoods_vec_vec_t lls;
 	calculate_likelihoods( mm, _data.get_text(), lls );
-	bg_model_t bg( _data, lls, freqs_with_pseudo_counts, W );
-
+	bg_model_t bg( W, freqs_with_pseudo_counts, &lls );
+    base_to_wmer_likelihoods_calculator( _data, *bg.base_LLs, bg.wmer_LLs );
 
 	//
 	// Build model
